# Leak Center API Tool

A Python script to query the Leak Center API for leaked credentials and extract structured data. The script supports various search options, filters, and output formats.

## Features

- Query the Leak Center API by domain, leak ID, or date range
- Filter results by tag (account)
- Extract detailed information from leak content, including:
  - URL/Server
  - Username/Email
  - Password
  - IP Address
  - PC Name
  - Logged In User
  - Timestamp
  - Session Cookies
  - Other Cookies
- Export results to CSV files
- Remove duplicates
- Optional environment variable support for credentials

## Installation

1. Clone this repository
2. Install the required dependencies:

```bash
pip install -r requirements.txt
```

## Configuration

The script supports two methods of configuration:

### 1. File-based configuration (Default)

- `auth.txt`: Contains login credentials in the format `username,password`
- `input.txt`: Contains the domain to query
- `tags.txt`: Contains filtering tags, one per line
- `leakid.txt`: Contains a leak ID to search for (optional)

### 2. Environment-based configuration (.env file)

Create a `.env` file with the following variables:

```
# Leak Center API Credentials
LEAK_CENTER_USERNAME=your_email@example.com
LEAK_CENTER_PASSWORD=your_password
LEAK_CENTER_CLIENT_ID=client-api
LEAK_CENTER_CLIENT_SECRET=comfy-litigate-embargo-forelimb

# API Endpoints
LEAK_CENTER_AUTH_URL=https://app.leak.center/uaa/oauth/token
LEAK_CENTER_LEAKS_ENDPOINT=https://app.leak.center/svc-saas/leak/search

# Default Tags (comma-separated)
DEFAULT_TAGS=account

# Debug Settings
DEBUG_REGEX=false
```

## Usage

Run the script:

```bash
python main.py
```

The script will:

1. Prompt you to use environment variables if a `.env` file is found
2. Authenticate with the API
3. Ask for a domain to query (or use one from input.txt)
4. Ask if you want to use a leak ID (or use one from leakid.txt)
5. Prompt for an optional date range
6. Query the API and process the results
7. Save the results to CSV files

### Search Options

#### 1. Domain Search

Enter a domain (e.g., `example.com`) to search for leaks related to that domain.

#### 2. Leak ID Search

You can provide a specific leak ID (e.g., `ead616ee-ea60-3fcd-99d3-424265fa4206`) to filter the results to a specific leak. The script will:
- Check if `leakid.txt` exists and contains a leak ID
- Ask if you want to use this leak ID
- Allow you to enter a different leak ID

#### 3. Date Range Search

The script supports multiple date formats for filtering by date range:

- ISO format: `2024-02-01 TO 2024-12-31`, `2024-02-01 TO *` (from date to present)
- Year range: `2022-2023`
- Month range: `may 21 to june 23`
- European format: `23.1.24-30.5.24`

Examples:
- `2024-02-01 TO *` - From February 1, 2024, to present
- `2024-02-01 TO 2025-01-31` - Date range with ISO format
- `2022-2023` - The years 2022 to 2023
- `may 21 to june 23` - From May 2021 to June 2023
- `23.1.24-30.5.24` - From January 23, 2024, to May 30, 2024

### Output Files

The script generates two CSV files:
- `output_data_[domain]_v[version]_domain_emails.csv`: Contains accounts with email addresses matching the queried domain
- `output_data_[domain]_v[version]_external_emails.csv`: Contains accounts with email addresses from other domains

### CSV Format

The CSV files include the following columns:
1. `URL` - The website or service URL
2. `User` - Username or email address
3. `Password` - Password for the account
4. `IP` - IP address associated with the leak
5. `PC` - Computer name
6. `LoggedInUser` - Username of the logged-in user
7. `Time` - Timestamp of the leak
8. `SessionCookie` - Session cookie value
9. `OtherCookies` - Other cookie values
10. `leakPublishDate` - Date when the leak was published
11. `fileName` - Source file name

## Advanced Features

### Filtering by Tags

You can filter results by specifying the tag in the `tags.txt` file or in the `.env` file. The supported tag is:
- account

### Enhanced Data Extraction

The script can parse advanced data formats that include additional fields like:
- IP addresses
- PC names
- Logged-in users
- Timestamps
- Session cookies
- Other cookies

These are typically found in formats like:
```
URL:username:password|IP:1.2.3.4|PC:DESKTOP-123|LoggedInUser:admin|Time:2024-01-01|SessionCookie:abc123|OtherCookies:xyz789
```

## Troubleshooting

- If authentication fails, check your credentials in `auth.txt` or `.env`
- If no results are returned, try adjusting your search parameters or tags
- For debug mode, set `DEBUG_REGEX=true` in your `.env` file

## License

This project is proprietary and confidential. All rights reserved. 